summaryrefslogtreecommitdiffstats
path: root/src/lib/dhcpsrv/srv_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/dhcpsrv/srv_config.h')
-rw-r--r--src/lib/dhcpsrv/srv_config.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/lib/dhcpsrv/srv_config.h b/src/lib/dhcpsrv/srv_config.h
index 123834ff7b..5f3ce4ab62 100644
--- a/src/lib/dhcpsrv/srv_config.h
+++ b/src/lib/dhcpsrv/srv_config.h
@@ -360,16 +360,16 @@ public:
control_socket_ = control_socket;
}
- /// @brief Returns queue control information
- /// @return pointer to the queue control information
- const isc::data::ConstElementPtr getQueueControlInfo() const {
- return (queue_control_);
+ /// @brief Returns DHCP queue control information
+ /// @return pointer to the DHCP queue control information
+ const isc::data::ConstElementPtr getDHCPQueueControl() const {
+ return (dhcp_queue_control_);
}
- /// @brief Sets information about the queue control
- /// @param new queue control information
- void setQueueControlInfo(const isc::data::ConstElementPtr queue_control) {
- queue_control_ = queue_control;
+ /// @brief Sets information about the dhcp queue control
+ /// @param new dhcp queue control information
+ void setDHCPQueueControl(const isc::data::ConstElementPtr dhcp_queue_control) {
+ dhcp_queue_control_ = dhcp_queue_control;
}
/// @brief Returns pointer to the dictionary of global client
@@ -663,8 +663,8 @@ private:
/// @brief Pointer to the control-socket information
isc::data::ConstElementPtr control_socket_;
- /// @brief Pointer to the queue-control information
- isc::data::ConstElementPtr queue_control_;
+ /// @brief Pointer to the dhcp-queue-control information
+ isc::data::ConstElementPtr dhcp_queue_control_;
/// @brief Pointer to the dictionary of global client class definitions
ClientClassDictionaryPtr class_dictionary_;